######################################################################
#
# English Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.
#
# Under the 'text macros' comments are text macros of the form:
# _macroname_[l=ar] {macro value}
# Everything between the[l=ar] {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textdefaultcontent_[l=ar] { لم يتمكن الحصول على الصفحة المطلوبة يرجو استعمال الزر "وراء" أو الزر "موقع" في أعلى الصفحة للرجوع إلى المكتبة الإلكترونية قرينستون.}

_textdefaulttitle_[l=ar] {خطأ جسدل}

_collectionextra_[l=ar] { هذه المجموعة تحتوي على:_about:numdocs_ وثيقة. 
آخر مرة تم بناؤها _about:builddate_ يوم من قبل. }

_textimagecollection_[l=ar] {}
_textimageabout_[l=ar] {حول الصفحة}
_textimagehome_[l=ar] {الصفحة الرئيسية}
_textimagehelp_[l=ar] {صفحة المساعدة}
_textimagepref_[l=ar] {صفحة الخيارات}
_textimagegreenstone_[l=ar] {برنامج المكتبة الإلكترونية قرينستون}

_textimagesearch_[l=ar] {البحث عن مصطلح معين}
_textimageTitle_[l=ar] {استعرض العناوين حسب الترتيب الهجائي}
_textimageList_[l=ar] {استعرض الوثيقة}
_textimageCreator_[l=ar] {استعرض المؤلفين حسب الترتيب الهجائي}
_textimageSeries_[l=ar] {استعرض حسب الإصدار}
_textimageDate_[l=ar] {استعرض حسب التاريخ}
_textimageSubject_[l=ar] {استعرض حسب صنف الموضوع }
_textimageOrganization_[l=ar] {استعرض حسب اسم المنظمة}
_textimageHowto_[l=ar] {استعرض كيف يتم التصنيف}
_textimageTopic_[l=ar] {استعرض مواضيع خاصة}
_textimageBrowse_[l=ar] {استعرض}
_textimagePeople_[l=ar] {استعرض المساهمون حسب الترتيب الهجائي}

_texticontabsearchgreen_{بحث}
_texticontabdategreen_{التواريخ}
_texticontabseriesgreen_{السلاسل}
_texticontabauthorgreen_{المؤلفون أ-ي}
_texticontabtitlegreen_{العناوين أ-ي}
_texticontablistgreen_[l=ar] {عرض}
_texticontabsubjectgreen_{محاور}
_texticontaborggreen_{منظمة}
_texticontabhowgreen_{كيف}
_texticontabtopicgreen_{مواضيع}
_texticontabbrwsegreen_{استعرض}
_texticontabPeoplegreen_{المساهمون أ-ي}

_texticontext_[l=ar] {شاهد الوثيقة}
_texticonclosedbook_[l=ar] {افتح هذه الوثيقة و شاهد الفهرس}
_texticonnext_[l=ar] {إلى الجزء القادم}
_texticonprev_[l=ar] {إلى الجزء السابق}

_page_[l=ar] {الصفحة}
_pages_[l=ar] {الصفحات}
_of_[l=ar] { من }
_vol_[l=ar] {حجم}
_num_[l=ar] {رقم}

_textmonth00_[l=ar] {}
_textmonth01_[l=ar] {يناير}
_textmonth02_[l=ar] {فبراير}
_textmonth03_[l=ar] {مارس}
_textmonth04_[l=ar] {أبريل}
_textmonth05_[l=ar] {مايو}
_textmonth06_[l=ar] {حزيران}
_textmonth07_[l=ar] {يونيو}
_textmonth08_[l=ar] {أغسطس}
_textmonth09_[l=ar] {سبتمبر}
_textmonth10_[l=ar] {أكتوبر}
_textmonth11_[l=ar] {نوفمبر}
_textmonth12_[l=ar] {ديسمبر}

_Document_[l=ar] {الوثيقة}
_Section_[l=ar] {الجزء}
_Paragraph_[l=ar] {فقرة}

_magazines_[l=ar] {المجلات}

_nzdlpagefooter_[l=ar] {<p>_iconblankbar_
<p><a href="_gwcgi_">مشروع المكتبة الإلكترونية لنيوزيلندا</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">مركز الإعلام الآلي مركز الإعلام الآلي</a>, 
<a href="http://www.waikato.ac.nz">جامعة وايكاتو</a>, نيوزيلندا}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "الموقع" ## top_nav_button ## chome ##
_httpiconchomeof_[l=ar] {_httpimg_/chomeof.gif}
_httpiconchomeon_[l=ar] {_httpimg_/chomeon.gif}
_widthchomex_[l=ar] {43}
_heightchomex_[l=ar] {20}

## " مساعدة" ## top_nav_button ## chelp ##
_httpiconchelpof_[l=ar] {_httpimg_/chelpof.gif}
_httpiconchelpon_[l=ar] {_httpimg_/chelpon.gif}
_widthchelpx_[l=ar] {36}
_heightchelpx_[l=ar] {20}

## "الخيارات" ## top_nav_button ## cpref ##
_httpiconcprefof_[l=ar] {_httpimg_/cprefof.gif}
_httpiconcprefon_[l=ar] {_httpimg_/cprefon.gif}
_widthcprefx_[l=ar] {87}
_heightcprefx_[l=ar] {20}

## "مساعدة" ## green_title ## h_help ##
_httpiconhhelp_[l=ar] {_httpimg_/h\_help.gif}
_widthhhelp_[l=ar] {200}
_heighthhelp_[l=ar] {57}

## "المؤلفون أ-ي" ## nav_bar_button ## tauth ##
_httpicontauthgr_[l=ar] {_httpimg_/tauthgr.gif}
_httpicontauthof_[l=ar] {_httpimg_/tauthof.gif}
_httpicontauthon_[l=ar] {_httpimg_/tauthon.gif}
_widthtauthx_[l=ar] {110}
_heighttauthx_[l=ar] {17}

## "السلاسل" ## nav_bar_button ## tser ##
_httpicontsergr_[l=ar] {_httpimg_/tsergr.gif}
_httpicontserof_[l=ar] {_httpimg_/tserof.gif}
_httpicontseron_[l=ar] {_httpimg_/tseron.gif}
_widthtserx_[l=ar] {87}
_heighttserx_[l=ar] {17}

## "التواريخ" ## nav_bar_button ## tdate ##
_httpicontdategr_[l=ar] {_httpimg_/tdategr.gif}
_httpicontdateof_[l=ar] {_httpimg_/tdateof.gif}
_httpicontdateon_[l=ar] {_httpimg_/tdateon.gif}
_widthtdatex_[l=ar] {87}
_heighttdatex_[l=ar] {17}

## "المواضيع" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_[l=ar] {_httpimg_/tsubjgr.gif}
_httpicontsubjon_[l=ar] {_httpimg_/tsubjon.gif}
_httpicontsubjof_[l=ar] {_httpimg_/tsubjof.gif}
_widthtsubjx_[l=ar] {87}
_heighttsubjx_[l=ar] {17}

## "المنظمة" ## nav_bar_button ## torg ##
_httpicontorggr_{_httpimg_/torggr.gif}
_httpicontorgon_{_httpimg_/torgon.gif}
_httpicontorgof_{_httpimg_/torgof.gif}
_widthtorgx_[l=ar] {109}
_heighttorgx_[l=ar] {17}

## "كيف" ## nav_bar_button ## thow ##
_httpiconthowgr_{_httpimg_/thowgr.gif}
_httpiconthowon_{_httpimg_/thowon.gif}
_httpiconthowof_{_httpimg_/thowof.gif}
_widththowx_[l=ar] {87}
_heightthowx_[l=ar] {17}

## "مادة" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_{_httpimg_/ttopicgr.gif}
_httpiconttopicon_{_httpimg_/ttopicon.gif}
_httpiconttopicof_{_httpimg_/ttopicof.gif}
_widthttopicx_[l=ar] {87}
_heightttopicx_[l=ar] {17}

## "استعرض" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_{_httpimg_/tbrwsegr.gif}
_httpicontbrwseon_{_httpimg_/tbrwseon.gif}
_httpicontbrwseof_{_httpimg_/tbrwseof.gif}
_widthtbrwsex_[l=ar] {87}
_heighttbrwsex_[l=ar] {17}

## "بحث" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_[l=ar] {_httpimg_/tsrchgr.gif}
_httpicontsrchof_[l=ar] {_httpimg_/tsrchof.gif}
_httpicontsrchon_[l=ar] {_httpimg_/tsrchon.gif}
_widthtsrchx_[l=ar] {87}
_heighttsrchx_[l=ar] {17}

## "العناوين أ-ي" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_[l=ar] {_httpimg_/ttitlgr.gif}
_httpiconttitlof_[l=ar] {_httpimg_/ttitlof.gif}
_httpiconttitlon_[l=ar] {_httpimg_/ttitlon.gif}
_widthttitlx_[l=ar] {87}
_heightttitlx_[l=ar] {17}

## "المساهمون" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_[l=ar] {_httpimg_/tpeopgr.gif}
_httpicontpeopof_[l=ar] {_httpimg_/tpeopof.gif}
_httpicontpeopon_[l=ar] {_httpimg_/tpeopon.gif}
_widthtpeopx_[l=ar] {97}
_heighttpeopx_[l=ar] {17}



######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_[l=ar] {حول هذه المجموعة}

_textsubcols1_[l=ar] {<p> المجموعة الكاملة تحتوي على _1 _ جزء مجموعة:<blockquote>}

_textsubcols2_[l=ar] {</blockquote>
تستطيع أن تتحقق  (و تصحح) أي مجموعة أنت بصدد الإستعمال في صفحة الخيارات}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "حول" ## green_title ## h_about ##
_httpiconhabout_[l=ar] {_httpimg_/h\_about.gif}
_widthhabout_[l=ar] {200}
_heighthabout_[l=ar] {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textTitlepage_[l=ar] {_texticonhtitle_}
_textCreatorpage_[l=ar] {_texticonhauth_}
_textSubjectpage_[l=ar] {_texticonhsubj_}
_textSeriespage_[l=ar] {_texticonhser_}
_textDatepage_[l=ar] {_texticonhdate_}
_textHowtopage_[l=ar] {_texticonhhow_}
_textOrganizationpage_[l=ar] {_texticonhorg_}
_textBrowsepage_[l=ar] {_texticonhbrwse_}
_textPeoplepage_[l=ar] {_texticonhpeople_}

_texticonhtitle_[l=ar] {العناوين أ-ي}
_texticonhauth_[l=ar] {المؤلفون أ-ي}
_texticonhsubj_[l=ar] {المواضيع}
_texticonhser_[l=ar] {السلاسل}
_texticonhdate_[l=ar] {التواريخ}
_texticonhhow_[l=ar] {كيف}
_texticonhorg_[l=ar] {المنظمات}
_texticonhbrwse_[l=ar] {استعرض}
_texticonhpeople_[l=ar] {المساهمون أ-ي}

_texticonopenbookshelf_[l=ar] {أغلق هذا الجزء من المكتبة}
_texticonclosedbookshelf_[l=ar] {افتح هذا الجزء من المكتبة و شاهد محتواه}
_texticonopenbook_[l=ar] {أغلق هذا الكتاب}
_texticonclosedfolder_[l=ar] {افتح هذا الملف و استعرض محتواه}
_texticonclosedfolder2_[l=ar] { افتح الفصل:}
_texticonopenfolder_[l=ar] {أغلق هذا الملف}
_texticonopenfolder2_[l=ar] { أغلق الجزء:}
_texticonsmalltext_[l=ar] {شاهد هذا الجزء من النص}
_texticonsmalltext2_[l=ar] { شاهد النص: }
_texticonpointer_[l=ar] {الجزء الحالي}
_texticondetach_[l=ar] {افتح هذه الصفحة في نافذة جديدة}
_texticonhighlight_[l=ar] {أظهر كلمات البحث}
_texticonnohighlight_[l=ar] {لا تظهر كلمات البحث}
_texticoncontracttoc_[l=ar] {قوض الفهرس}
_texticonexpandtoc_[l=ar] {أبسط الفهرس}
_texticonexpandtext_[l=ar] {أعرض كل النص}
_texticoncontracttext_[l=ar] {لا تعرض إلا نص الجزء المختار}
_texticonwarning_[l=ar] {<b> إشعار: </b>}
_texticoncont_[l=ar] { واصل؟}

_textltwarning_[l=ar] {
<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_ التوسع في النص هنا سيجلب للمستعرض كميات كبيرة من المعلومات للعرض _imagecont_
</td></tr></table></center>
}

_textgoto_[l=ar] {اذهب إلى الصفحة}
_textintro_[l=ar] { <i>( النص الإفتتاحي)</i>}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "العناوين أ-ي" ## green_title ## h_title ##
_httpiconhtitle_[l=ar] {_httpimg_/h\_title.gif}
_widthhtitle_[l=ar] {200}
_heighthtitle_[l=ar] {57}

## "المؤلفون أ-ي" ## green_title ## h_auth ##
_httpiconhauth_[l=ar] {_httpimg_/h\_auth.gif}
_widthhauth_[l=ar] {200}

## "المواضيع" ## green_title ## h_subj ##
_httpiconhsubj_[l=ar] {_httpimg_/h\_subj.gif}
_widthhsubj_[l=ar] {200}
_heighthsubj_[l=ar] {57}

## "السلاسل" ## green_title ## h_ser ##
_httpiconhser_[l=ar] {_httpimg_/h\_ser.gif}
_widthhser_[l=ar] {200}
_heighthser_[l=ar] {57}

## "التواريخ" ## green_title ## h_date ##
_httpiconhdate_[l=ar] {_httpimg_/h\_date.gif}
_widthhdate_[l=ar] {200}
_heighthdate_[l=ar] {57}

## "كيف" ## green_title ## h_how ##
_httpiconhhow_[l=ar] {_httpimg_/h\_how.gif}
_widthhhow_[l=ar] {200}
_heighthhow_[l=ar] {57}

## "المواد" ## green_title ## h_topic ##
_httpiconhtopic_[l=ar] {_httpimg_/h\_topic.gif}
_widthhtopic_[l=ar] {200}
_heighthtopic_[l=ar] {57}

## "المنظمة" ## green_title ## h_org ##
_httpiconhorg_[l=ar] {_httpimg_/h\_org.gif}
_widthhorg_[l=ar] {250}
_heighthorg_[l=ar] {57}

## "استعرض" ## green_title ## h_brwse ##
_httpiconhbrwse_[l=ar] {_httpimg_/h\_brwse.gif}
_widthhbrwse_[l=ar] {200}
_heighthbrwse_[l=ar] {57}

## "المساهمون" ## green_title ## h_people ##
_httpiconhpeople_[l=ar] {_httpimg_/h\_people.gif}
_widthhpeople_[l=ar] {200}
_heighthpeople_[l=ar] {57}

## "واصل؟" ## top_nav_button ## cont ##
_httpiconcontoff_[l=ar] {_httpimg_/contoff.gif}
_httpiconconton_[l=ar] {_httpimg_/conton.gif}
_widthcontx_[l=ar] {76}
_heightcontx_[l=ar] {17}

## "توسع في النص" ## document_button ## eallt ## 
_httpiconealltof_[l=ar] {_httpimg_/ealltof.gif}
_httpiconeallton_[l=ar] {_httpimg_/eallton.gif}
_widthealltx_[l=ar] {65}
_heightealltx_[l=ar] {30}

## "قوض المحتوى" ## document_button ## econc ##
_httpiconeconcof_[l=ar] {_httpimg_/econcof.gif}
_httpiconeconcon_[l=ar] {_httpimg_/econcon.gif}
_widtheconcx_[l=ar] {65}
_heighteconcx_[l=ar] {30}

## "أفصل" ## document_button ## edtch ##
_httpiconedtchof_[l=ar] {_httpimg_/edtchof.gif}
_httpiconedtchon_[l=ar] {_httpimg_/edtchon.gif}
_widthedtchx_[l=ar] {65}
_heightedtchx_[l=ar] {30}

## "توسع في المحتوى" ## document_button ## eexpc ##
_httpiconeexpcof_[l=ar] {_httpimg_/eexpcof.gif}
_httpiconeexpcon_[l=ar] {_httpimg_/eexpcon.gif}
_widtheexpcx_[l=ar] {65}
_heighteexpcx_[l=ar] {30}

## "قوض النص" ## document_button ## etsec ##
_httpiconetsecof_[l=ar] {_httpimg_/etsecof.gif}
_httpiconetsecon_[l=ar] {_httpimg_/etsecon.gif}
_widthetsecx_[l=ar] {65}
_heightetsecx_[l=ar] {30}

## "الإظهار" ## document_button ## ehl ##
_httpiconehlof_[l=ar] {_httpimg_/ehlof.gif}
_httpiconehlon_[l=ar] {_httpimg_/ehlon.gif}
_widthehlx_[l=ar] {65}
_heightehlx_[l=ar] {30}

## "عدم الإظهار" ## document_button ## enhl ##
_httpiconenhlof_[l=ar] {_httpimg_/enhlof.gif}
_httpiconenhlon_[l=ar] {_httpimg_/enhlon.gif}
_widthenhlx_[l=ar] {65}
_heightenhlx_[l=ar] {30}



######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_[l=ar] {_If_(_thislast_, النتائج _thisfirst_ - _thislast_ للطلب:  _cgiargq_, لا يوجد مقابل للطلب: _cgiargq_)}
_textnoquerytitle_[l=ar] {صفحة البحث}

_texticonthispage_[l=ar] {ابحث}
_textsome_[l=ar] {_If_(_cgiargb_, مصنف, بعض)}
_textall_[l=ar] {_If_(_cgiargb_, بوليان, كل)}
_texticonqueryresultsbar_[l=ar] {}
_textfreqmsg1_[l=ar] { عدد الكلمات: }
_textpostprocess_[l=ar] {_If_(_quotedquery_,<br><i> بعد التحليل لايحاد _quotedquery_</i>
)}

_textmorethan_[l=ar] { أكثر من}
_textapprox_[l=ar] {حول}
_textnodocs_[l=ar] { لا يوجد ملف يقابل الطلب. }
_text1doc_[l=ar] {1 ملف يطابق الطلب.}
_textlotsdocs_[l=ar] { ملفات يطابقون الطلب.}
_textmatches_[l=ar] {المطابقات}
_textbeginsearch_[l=ar] {ابدأ البحث}

# the textselect macro may need to be overridden for some collections
# _hselection_, _jselection_ and _nselection_ are set from within the server
# some or all of them may remain unset
_textselect_[l=ar] {_If_(_cgiargb_,_textadvancedsearch_,_textsimplesearch_)}

_textsimplesearch_[l=ar] { ابحث عن _If_(_hselection_, _hselection_)_If_(_jselection_,_textjselect_)_If_(_gselection_, في _gselection_ المستوى)_If_(_nselection_, في _nselection_ اللغة) 
التي تحتوي على _querytypeselection_ الكلمات }

_textadvancedsearch_[l=ar] { ابحُث_If_(_hselection_, _hselection_, _defaultindextext_)_If_(_jselection_,_textjselect_)_If_(_gselection_, في_gselection_ المستوى)_If_(_nselection_, في _nselection_ اللغة) 
التي تحتوي على _querytypeselection_ الكلمات }

_textjselect_[l=ar] {_If_(_hselection_, من) _jselection_}

_querytypeselection_[l=ar] {
<select name="t">
<option value="1"_If_(_cgiargt_, selected)>_textsome_
<option value="0"_If_(_cgiargt_,, selected)>_textall_
</select>
}

_textstemon_[l=ar] { (تجاهل نهاية الكلمات)}
_textclearhistory_[l=ar] {افرغ المقيد}
_textexpand_[l=ar] {توسع}
_textcontract_[l=ar] {قوض}
_textsearchhistory_[l=ar] {ابحث في المقيد}
_textquery_[l=ar] {الطلب}
_textresults_[l=ar] {النتائج}
_textview_[l=ar] {شاهد}
_textnohistory_[l=ar] {البحث في المقيد ليس متوفر}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "ابحث" ## green_title ## h_search ##
_httpiconhsearch_[l=ar] {_httpimg_/h\_search.gif}
_widthhsearch_[l=ar] {200}
_heighthsearch_[l=ar] {57}

## "النتائج" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_[l=ar] {_httpimg_/qryresb.gif}
_widthqryresb_[l=ar] {_pagewidth_}
_heightqryresb_[l=ar] {17}

## "اعرض" ## hand_made ##
_httpicondisplay_[l=ar] {_httpimg_/display.gif}
_widthdisplay[l=ar] {60}
_heightdisplay_[l=ar] {20}



######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textsearchprefs_[l=ar] {الخيارات في البحث}
_textcollectionprefs_[l=ar] {الخيارات في المجموعة}
_textpresentationprefs_[l=ar] { الخيارات في التقديم}
_textpreferences_[l=ar] {الخيارات}
_textstem_[l=ar] {تجاهل نهاية الكلمات}
_textnostem_[l=ar] { كل الكلمة يجب أن تطابق }
_textprefop_[l=ar] { أعيد حتى _maxdocoption_ مطابق وكل صفحة تحتوي على _hitsperpageoption_ مطابق.}
_textextlink_[l=ar] { الحصول على صفحات الإنترنت الخارجية}
_textintlink_[l=ar] { مصدر الملفات تحصل عليها من}
_textlanguage_[l=ar] { لغة الواجهة:}
_textencoding_[l=ar] { رموز التخزين:}
_textformat_[l=ar] { صيغة الواجهة:}
_textall_[l=ar] {كل}
_textsimplemode_[l=ar] {طريقة الطلب البسيط}
_textadvancedmode_[l=ar] { طريقة الطلب المتقدمة (يمكن استعمال البحث البوليان المستعمل |, &, ! و القوسين)}
_textlinkinterm_[l=ar] {عبر صفحة وسطى}
_textlinkdirect_[l=ar] {اذهب إلى هناك}
_textdigitlib_[l=ar] {المكتبة الإلكترونية}
_textweb_[l=ar] {الإنترنت}
_textlangeng_[l=ar] {إنكليزي}
_textlanggerman_[l=ar] {ألماني}
_textlangmaori_[l=ar] {M_amn_ori}
_textlangchinese_[l=ar] {صيني}
_textgraphical_[l=ar] {تخطيطي}
_texttextual_[l=ar] {النص}
_textcollectionoption_[l=ar] {<p>
الفصول للانضمام:
<br>}
_textfcoption_[l=ar] {تحتوي على قضيب الاستعراض في أعلى صفحات النص}
_texthloption_[l=ar] {إظهار كلمات البحث في النص}
_texthistorydisplay_[l=ar] {عرض تاريخ البحث}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "الخيارات" ## green_title ## h_pref ##
_httpiconhpref_[l=ar] {_httpimg_/h\_pref.gif}
_widthhpref_[l=ar] {200}
_heighthpref_[l=ar] {57}



######################################################################
# 'delete search history' page
package delhistory
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textdsh_[l=ar] {Delete Search History}

_textselectdelete_[l=ar] {<a href="_httpclearhistory_&hdh=1"> امحي كل السجلات </a>أو انتقي السجلات <select name=hmode><option value=save> لعدم المحي <option value=delete selected> امحي </select><br> السجلات بإدخال الأرقام المناسبة في العلبة,,<br> أو بالضغط على العلبة المقابلة لكل سجل.<br> الأرقام المقبولة هي 1, 2, 3, ... الخ }

_textclearselected_[l=ar] {المحي مختار}
_textselect_[l=ar] {اختار}


#------------------------------------------------------------
# icons
#------------------------------------------------------------



######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_[l=ar] {Help}
_textSearchshort_[l=ar] {search for particular words}
_textSeriesshort_[l=ar] {access publications by series}
_textDateshort_[l=ar] {access publications by date}
_textSubjectshort_[l=ar] {access publications by subject}
_textTitleshort_[l=ar] {access publications by title}
_textBrowseshort_[l=ar] {browse publications}
_textCreatorshort_[l=ar] {access publications by author}
_textOrganizationshort_[l=ar] {access publications by organization}
_textHowtoshort_[l=ar] {access publications by how to listing}
_textTopicshort_[l=ar] {access publications by topic}
_textPeopleshort_[l=ar] {access publications by people}
_textdefaultshorttext_[l=ar] {undefined classification}

_textSearchlong_[l=ar] { <p>You can <i>search for particular words</i> that
appear in the text from the "search" page. This is the first page that
comes up when you begin, and can be reached from other pages by pressing
the <i>search</i> button.  }

_textTitlelong_[l=ar] { <p>You can <i>access publications by title</i> by
pressing the <i>titles a-z</i> button.  This brings up a list of books in
alphabetic order.  }

_textOrganizationlong_[l=ar] { <p>You can <i>access publications by
organization</i> by pressing the <i>organization</i> button.  This brings
up a list of organizations.  }

_textHowtolong_[l=ar] { <p>You can <i>access publications by how to listing</i>
by pressing the <i>how to</i> button.  This brings up a list of how to
strings.  }

_textCreatorlong_[l=ar] { <p>You can <i>access publications by author</i> by
pressing the <i>authors a-z</i> button.  This brings up a list of books,
sorted by author name.  }

_textTopiclong_[l=ar] { <p>You can <i>access publications by topic</i> by
pressing the <i>topic</i> button.  This brings up a list of topics to
browse.  }

_textSubjectlong_[l=ar] { <p>You can <i>access publications by subject</i> by
pressing the <i>subjects</i> button.  This brings up a list of subjects,
represented by bookshelves.  }

_textSerieslong_[l=ar] { <p>You can <i>access publications by series</i> by
pressing the <i>series</i> button.  This brings up a list of those series
which are currently in the collection.  }

_textDatelong_[l=ar] { <p>You can <i>access publications by date</i> by pressing
the <i>dates</i> button.  This brings up a list of all the issues, sorted
chronologically.  }

_textBrowselong_[l=ar] { <p>You can <i>browse publications</i> by pressing the
<i>browse</i> button.  }

_textPeoplelong_[l=ar] { <p>You can <i>access publications by people</i> by
pressing the <i>people a-z</i> button.  This brings up a list of entries,
sorted by surname.  }

_textdefaultlongtext_[l=ar] { <p>Click on the <i>unknown</i> button to browse
publications (listing is sorted by an unknown field).  }

_texthelptopics_[l=ar] {
<h2 align=left>Topics</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
  _topicreadingdocs_
  <li><a href="\#searching">How to search for particular words</a>
<ul>
  <li><a href="\#query-terms">Search terms</a>
  <li><a href="\#query-type">Query type</a>
  <li><a href="\#scope-of-queries">Scope of queries</a>
</ul>
  <li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">Collection preferences</a>
  <li><a href="\#pres-prefs">Presentation preferences</a>
  <li><a href="\#search-prefs">Search preferences</a>
</ul>
</ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_[l=ar] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_[l=ar] {How to read the documents}
_booktextreadingdocs_[l=ar] {How to read the books}
_bibtextreadingdocs_[l=ar] {Getting more information on a bibliography item}

_texthelpreadingdocs_[l=ar] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>You can tell when you have arrived at an individual document because its
title and author appear at the top left of the page. Beside these is the
number of the current page, a box that allows you to select a new page, and
forward and backward arrows.

<p>Underneath is the text of the current section. When you have read
through it, there are arrows at the bottom to take you on to the next
section or back to the previous one.

<p>Below the title and author are three buttons. Click on <i>expand
text</i> to expand out the whole text of the current document. If the
document is large, this could take a long time and use a lot of memory!
Click on <i>detach</i> to make a new browser window for this
document. (This is useful if you want to compare documents, or read two at
once.)  Finally, when you do a search the words you search for are
highlighted.  Click on <i>no highlighting</i> to remove the highlighting.
<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Click on the arrow to go to the next section ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... or back to the previous section</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Display all text, or not</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Open this page in a new window</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Highlight search terms, or not</td></tr>
</table>

}

_booktexthelpreadingdocs_[l=ar] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>You can tell when you have arrived at an individual book because there
is a photograph of its front cover at the top left of the page.  Beside the
photograph is a table of contents with an arrow marking where you are.
This table is expandable: click on the folders to open them or close them.
Click on the open book at the top to close it.

<p>Underneath is the text of the current section.  When you have read
through it, there are arrows at the bottom to take you on to the next
section or back to the previous one.

<p>Below the photograph are four buttons. Click on <i>expand text</i> to
expand out the whole text of the current section, or book.  If the book is
large, this could take a long time and use a lot of memory! Click on
<i>expand contents</i> to expand out the whole table of contents so that
you can see the titles of all chapters and subsections. Click on
<i>detach</i> to make a new browser window for this book.  (This is useful
if you want to compare books, or read two at once.) Finally, when you do a
search the words you search for are highlighted. Click on <i>no
highlighting</i> to remove highlighting.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconbshelf_" border="0"></td><td>Open this bookshelf</td></tr>
<tr><td><img src="_httpiconopenbook_" border="0"></td><td><img 
src="_httpiconbook_" border="0"></td><td>Open/close this book</td></tr>
<tr><td colspan=2><img src="_httpiconitext_" border="0"></td><td>View this section of the text</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Display all text, or not</td></tr>
<tr><td><img src="_document:httpiconeexpcof_" border="0"></td><td><img
src="_document:httpiconeconcof_" border="0"></td><td>Expand table of contents, or not</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Open this page in a new window</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Highlight search terms, or not</td></tr>
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Click the arrow to go to the next section ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... or back to the previous section</td></tr>
</table>
}

_bibtexthelpreadingdocs_[l=ar] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Some bibliography items contain more information, such as an abstract.
You can tell from the query response page if this is the case because they 
are shown with the _icontext_ icon instead of the _iconblanktext_ icon.

<p>Clicking on the _icontext_ icon will give you more information about the
bibliography item.

<p> Below the bibliography item are two buttons. Click on <i>detach</i> to 
make a new browser window for this book. (This is useful if you want to compare
bibliography items.) Finally, when you do a search the words you search for are 
highlighted. Click on <i>no highlighting</i> to remove the highlighting.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Open this page in a new window</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Highlight search terms, or not</td></tr>
</table>
}

_texthelpsearching_[l=ar] {
<h2>How to search for particular words</h2>
<p>
  From the search page, you make a query in these simple steps:<p>
  
  <ol><li>Specify what documents you want to search
      <li>Say whether you want to search for all or just some of the words
      <li>Type in the words you want to search for
      <li>Click the <i>Begin Search</i> button
  </ol>

<p>When you make a query, the titles of twenty matching documents will be shown.
There is a button at the end to take you on to the next twenty documents.  From
there you will find buttons to take you on to the third twenty or back to the
first twenty, and so on.  Click the title of any document, or the little button
beside it, to see it.

<p>A maximum of 100 is imposed on the number of
  documents returned.  You can change this number by clicking the
  <i>preferences</i> button at the top of the page.<p>

<p>_iconblankbar_
<a name=query-terms>
<h3>Search terms</h3>

<p>Whatever you type into the query box is interpreted as a list of words
called "search terms."  Each term contains nothing but alphabetic characters
and digits.  Terms are separated by white space.  If any other characters such
as punctuation appear, they serve to separate terms just as though they were
spaces.  And then they are ignored.  You can't search for words that include
punctuation.

<p>For example, the query<p>
    <ul><kbd>Agro-forestry in the Pacific Islands: Systems for Sustainability (1993)</kbd></ul>
      <p>will be treated the same as<p>
      <ul><kbd>Agro forestry in the Pacific Islands  Systems for Sustainability  1993 </kbd></ul><p>

<p>_iconblankbar_
<a name=query-type>
<h3>Query type</h3>

<p>There are two different kinds of query.

<ul>
  <li>Queries for <b>all</b> of the words.  These look for documents that 
      contain all the words you have specified.  Documents that satisfy the
      query are displayed, in alphabetical order.<p>

  <li>Queries for <b>some</b> of the words.  Just list some terms that are
      likely to appear in the documents you are looking for.  Documents are
      displayed in order of how closely they match the query.  When determining

      the degree of match,

      <p><ul>
        <li> the more search terms a document contains, the closer it matches;
        <li> rare terms are more important than common ones;
        <li> short documents match better than long ones.
      </ul>
</ul>

<p>Use as many search terms as you like--a whole sentence, or even a
whole paragraph.  If you specify only
one term, documents will be ordered by its frequency of occurrence.<p>
_texthelpscope_
}

_textchangeprefs_[l=ar] {Changing your preferences}

_texthelppreferences_[l=ar] {<h2>_textchangeprefs_</h2>

<p>When you click the <i>preferences</i> button at the top of the page you will
be able to change some features of the interface to suit your own requirements.

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>Collection preferences</h3>

Some collections comprise several subcollections, which can be searched
independently or together, as one unit.  If so, you can select which
subcollections to include in your searches on the Preferences page.

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>Presentation preferences</h3>

Depending on the particular collection, there may be several options you can
set that control the presentation.

Collections of Web pages allow you to suppress the Greenstone navigation bar at
the top of each document page, so that once you have done a search you land at
the exact Web page that matches without any Greenstone header.  To do another
search you will have to use your browser's "back" button.  These collections
also allow you to suppress Greenstone's warning message when you click a link
that takes you out of the digital library collection and on to the Web itself.
And in some Web collections you can control whether the links on the "Search
Results" page take you straight to the actual URL in question, rather than to
the digital library's copy of the page.

Collections that are capable of being presented in different languages allow
you to specify the interface language.  If the language is Chinese, you can
also specify which of the standard Chinese encodings your browser uses.

Finally, all collections allow you to switch to a textual interface format
rather than the standard graphical one.  This is particularly useful for
visually impaired users who use large screen fonts or speech synthesizers for
output.

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>Search preferences</h3>
Two pairs of buttons control the case sensitivity and stemming of the searches
that you make. The first set of buttons controls whether upper and lower case
must match (case sensitivity).  The second set controls whether to ignore word
endings or not (stemming).

<p>For example, if the buttons <i>ignore case differences</i> and
<i>ignore word endings</i> are selected, the query<p>
    <ul><kbd>African building</kbd></ul>
      <p>will be treated the same as<p>
      <ul><kbd>africa builds</kbd></ul><p>
      because the uppercase letter in "African" will be transformed to
      lowercase, and  the suffixes "n" and "ing" will be removed from
      "African" and "building" respectively (also, "s" would be removed from
      "builds").

<p>You can also switch to an "advanced" query mode which allows you to
combine terms using AND (&), OR (|), and NOT (!). This allows you to
specify more precise queries.

<p>Finally, you can control the number of hits returned, and the number
presented on each screenful.

}

_texttanumbrowseoptions_[l=ar] {There are _numbrowseoptions_ ways to find information in this collection:}

_textsimplehelpheading_[l=ar] {How to find information}

_texthelpscope_[l=ar] {
<p>_iconblankbar_
<a name=scope-of-queries>
<h3 align=left>Scope of queries</h3>

<p>
In most collections you can choose different indexes to search. For example, there might
be author or title indexes. Or there might be chapter or paragraph indexes. Generally,
the full matching document is returned regardless of which index you search.
<p>If documents are books, they will be opened at the appropriate place.
}


#------------------------------------------------------------
# icons
#------------------------------------------------------------
